@@ -376,6 +376,9 @@ def startup() -> None:
     if os.path.exists(path(error_directory_location)) and os.listdir(path(error_directory_location)) == []:
         os.rmdir(path(error_directory_location))
 
+    if os.path.exists(isisdl_executable + ".old"):
+        os.unlink(isisdl_executable + ".old")
+
     if not is_windows:
         os.makedirs(path(config_dir_location), exist_ok=True)
         os.makedirs(systemd_dir_location, exist_ok=True)
@@ -638,13 +641,16 @@ def install_latest_version() -> None:
                 sys.exit(1)
 
             new_file = requests.get(asset["browser_download_url"], stream=True)
-            new_isisdl = os.path.join(tmp, correct_name)
+            new_isisdl = os.path.join(tmp, "tmp." + correct_name)
             with open(new_isisdl, "wb") as f:
                 shutil.copyfileobj(new_file.raw, f)
 
-            st = os.stat(new_isisdl)
-            os.chmod(new_isisdl, st.st_mode | stat.S_IEXEC)
-            os.replace(isisdl_executable, new_isisdl)
+            os.rename(isisdl_executable, isisdl_executable + ".old")
+            shutil.copyfile(new_isisdl, isisdl_executable)
+
+            st = os.stat(isisdl_executable)
+            os.chmod(isisdl_executable, st.st_mode | stat.S_IXUSR | stat.S_IXGRP | stat.S_IXOTH)
+
             ret = 0
 
     else:
